# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:archivelog_deletion_policy) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `ARCHIVELOG DELETION POLICY`
    The configuration can be set to default by setting it to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      archivelog_deletion_policy => 'BACKED UP 1 TIMES TO SBT',
      ...
    }
  DESC

  data_type('String[1]')

  to_translate_to_resource do |raw_resource|
    raw_resource['ARCHIVELOG_DELETION_POLICY']
  end

  def insync?(is)
    if should.casecmp('clear').zero?
      is.include?('(default)')
    else
      is.casecmp(should).zero?
    end
  end

  on_modify do
    if value.casecmp('clear').zero?
      rman("configure archivelog deletion policy #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    else
      rman("configure archivelog deletion policy to #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    end
  end
end
