# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:encryption_algorithm) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `ENCRYPTION ALGORITHM`.
    The configuration can be set to default by setting it to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      encryption_algorithm => 'AES256',
      ...
    }
  DESC

  newvalues(:clear, :CLEAR, :aes128, :AES128, :aes192, :AES192, :aes256, :AES256)
  data_type("Enum['clear','CLEAR','aes128','AES128','aes192','AES192','aes256','AES256','AES128 (default)']")

  to_translate_to_resource do |raw_resource|
    raw_resource['ENCRYPTION_ALGORITHM']
  end

  def insync?(is)
    if should.to_s.casecmp('clear').zero?
      is.to_s.include?('(default)')
    else
      is.casecmp(should).zero?
    end
  end

  on_modify do
    if value.casecmp('clear').zero?
      rman("configure encryption algorithm #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    else
      rman("configure encryption algorithm '#{value}'", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    end
  end
end
