# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

newproperty(:snapshot_controlfile_name) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Manage rman configuration for `SNAPSHOT CONTROLFILE NAME`.
    The configuration can be set to default by setting it to 'clear' (case insensitive).

    ora_rman_config { 'SID':
      ...
      snapshot_controlfile_name => '/u01/app/oracle/admin/snapcf_DB190.f',
      ...
    }
  DESC

  data_type('String[1]')

  to_translate_to_resource do |raw_resource|
    raw_resource['SNAPSHOT_CONTROLFILE_NAME']
  end

  def insync?(is)
    if should.casecmp('clear').zero?
      is.include?('(default)')
    else
      is.casecmp(should).zero?
    end
  end

  on_modify do
    if value.to_s.casecmp('clear').zero?
      rman("configure snapshot controlfile name #{value}", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    else
      rman("configure snapshot controlfile name to '#{value}'", { :sid => resource.sid, :target_conn => resource.target_conn, :catalog_conn => resource.catalog_conn })
    end
  end
end
