# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'win32/registry' if Facter.value(:kernel) == 'windows'
module PuppetX
  module EnterpriseModules
    module Oracle
      # docs
      module Directories
        def self.included(parent)
          parent.extend(Directories)
        end

        def confdir
          if Puppet::Util::Platform.windows?
            'database'
          else
            'dbs'
          end
        end

        def sep
          if Puppet::Util::Platform.windows?
            '\\'
          else
            '/'
          end
        end

        def remove_directories(_placeholder = nil, _options = {})
          remove_oracle_directory "#{oracle_base}#{sep}admin#{sep}#{name}"
          remove_oracle_directory "#{oracle_home}#{sep}#{confdir}#{sep}init#{name}.ora"
          remove_oracle_directory "#{oracle_home}#{sep}#{confdir}#{sep}spfile#{name}.ora"
          remove_oracle_directory "#{oracle_home}#{sep}#{confdir}#{sep}hc_#{name}.dat"
          remove_oracle_directory "#{oracle_home}#{sep}#{confdir}#{sep}lk#{name}.dat"
          remove_oracle_directory "#{oracle_home}#{sep}#{confdir}#{sep}orapw#{name}"
          remove_oracle_directory "#{oracle_base}#{sep}cfgtoolslog#{sep}dbca#{sep}#{name}"
        end

        def remove_oracle_directory(path)
          Puppet.debug "directories.rb: Removing file/directory #{path}"
          FileUtils.rm_rf path
        end

        def directories
          [
            oracle_base,
            oracle_home,
            "#{oracle_home}#{sep}#{confdir}",
            "#{oracle_base}#{sep}admin",
            "#{oracle_base}#{sep}cfgtoollogs",
            "#{oracle_base}#{sep}cfgtoollogs#{sep}dbca",
            "#{oracle_base}#{sep}cfgtoollogs#{sep}dbca#{sep}#{name}"
          ] + named_oracle_directories
        end

        def named_oracle_directories
          [
            "#{oracle_base}#{sep}admin#{sep}#{name}",
            "#{oracle_base}#{sep}admin#{sep}#{name}#{sep}adump",
            "#{oracle_base}#{sep}admin#{sep}#{name}#{sep}ddump",
            "#{oracle_base}#{sep}admin#{sep}#{name}#{sep}dpdump",
            "#{oracle_base}#{sep}admin#{sep}#{name}#{sep}hdump",
            "#{oracle_base}#{sep}admin#{sep}#{name}#{sep}pfile",
            "#{oracle_base}#{sep}admin#{sep}#{name}#{sep}scripts",
            "#{oracle_base}#{sep}admin#{sep}#{name}#{sep}scripts#{sep}log"
          ]
        end

        def oracle_directories_exists?
          named_oracle_directories.any? { |d| File.directory?(d) }
        end

        def create_directories(_placeholder = nil, _options = {})
          directories.each { |d| make_oracle_directory d }
        end

        def create_directory(path, _placeholder = nil, _options = {})
          make_oracle_directory path
        end

        def make_oracle_directory(path)
          Puppet.debug "directories.rb: Creating directory #{path}"
          FileUtils.mkdir_p path
          owned_by_oracle(path)
        end

        def owned_by_oracle(*path)
          Puppet.debug "directories.rb: Setting ownership for #{path}"
          if Puppet::Util::Platform.windows?
            command = "#{oracle_home}\\bin\\oradim.exe -ACL -setperm diag -USER ORA_#{oracle_home_name}_SVCACCTS -OBJTYPE dir -OBJPATH #{path[0]} -RECURSE false"
            Puppet::Util::Execution.execute(command)
          else
            FileUtils.chmod 0o775, path
            FileUtils.chown oracle_user, install_group, path
          end
        end

        def oracle_home_name
          reg = Win32::Registry::HKEY_LOCAL_MACHINE.open('SOFTWARE\\Oracle')
          reg.each_key do |regkey|
            next unless /^KEY_/.match?(regkey)

            home_reg = Win32::Registry::HKEY_LOCAL_MACHINE.open("SOFTWARE\\Oracle\\#{regkey}")
            return home_reg['ORACLE_HOME_NAME'] if home_reg['ORACLE_HOME'] == oracle_home
          end
        end
      end
    end
  end
end
