# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/command'
require 'puppet_x/enterprisemodules/oracle/settings'

module PuppetX
  module EnterpriseModules
    module Oracle
      # docs
      class OrapwdCommand < PuppetX::EnterpriseModules::Oracle::Command
        include Settings
        def initialize(options = {})
          super(:orapwd, options)
        end

        def execute(arguments)
          options = { :failonfail => true, :combine => true }
          value = ''
          if Puppet::Util::Platform.windows?
            oracle_home = configuration_value_for(@sid, 'oracle_home')
            command = "#{oracle_home}\\bin\\orapwd.exe #{arguments}"
          else
            command = command_string(arguments)
          end
          within_time(@timeout) do
            if Puppet::Util::Platform.windows?
              Puppet.debug "orapwd_command.rb: Executing command: #{@command} #{arguments}"
            else
              Puppet.debug "Executing #{@command} command: #{arguments} as #{os_user}"
            end
            value = Puppet::Util::Execution.execute(command, options)
          end
          value
        end
      end
    end
  end
end
